==> Gridcoin-Research-5.3.3.0.tar.gz: Gridcoin-Research-5.3.3.0/src/qt/locale/bitcoin_ur_PK.ts <==
<TS language="ur_PK" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>نیا ایڈریس بنائیں</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>نیا</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>سلیکٹڈ پتے کو کمپوٹر کی عارضی جگہ رکھیں</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>نقل</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>سلیکٹڈ پتے کو مٹائیں</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>مٹا</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>پاس فریز داخل کریں</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>نیا پاس فریز</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>نیا پاس فریز دہرائیں</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>رقم:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>چٹ</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation> پتہ</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Insufficient funds!</source>
        <translation>ناکافی فنڈز</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>رقم:</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Insufficient funds</source>
        <translation>ناکافی فنڈز</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
</context>
</TS>

==> Gridcoin-Research-5.4.9.0.tar.gz: Gridcoin-Research-5.4.9.0/src/qt/locale/bitcoin_ur_PK.ts <==
<TS language="ur_PK" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>نیا ایڈریس بنائیں</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>نیا</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>سلیکٹڈ پتے کو کمپوٹر کی عارضی جگہ رکھیں</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>نقل</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>سلیکٹڈ پتے کو مٹائیں</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>مٹا</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>پاس فریز داخل کریں</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>نیا پاس فریز</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>نیا پاس فریز دہرائیں</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>رقم:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>چٹ</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation> پتہ</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Insufficient funds!</source>
        <translation>ناکافی فنڈز</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>رقم:</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Insufficient funds</source>
        <translation>ناکافی فنڈز</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
</context>
</TS>
